CldImageWidget class

A widget that displays a Cloudinary-hosted image. Its constructor offers various attributes to customize image presentation. Ensure the publicId field is not null. It’s a required identifier for the image you want to display.

Inheritance

Constructors

CldImageWidget({required String publicId, Key? key, CldImageWidgetConfiguration? configuration, Cloudinary? cloudinary, String? version, String? extension, String? urlSuffix, String? assetType, String? deliveryType, Transformation? transformation, Map<String, String>? httpHeaders, ImageWidgetBuilder? imageBuilder, PlaceholderWidgetBuilder? placeholder, LoadingErrorWidgetBuilder? errorBuilder, Duration? placeholderFadeInDuration, int? memCacheWidth, int? memCacheHeight, String? cacheKey, int? maxWidthDiskCache, int? maxHeightDiskCache, double? width, double? height, Color? color, BlendMode? colorBlendMode, BoxFit? fit, ImageRepeat repeat = ImageRepeat.noRepeat, FilterQuality filterQuality = FilterQuality.low, bool matchTextDirection = false})

Properties

alignment → Alignment
How to align the image within its bounds.
finalinherited
cacheKey → String?
The target image's cache key.
finalinherited
cacheManager → BaseCacheManager?
Option to use cacheManager with other settings
finalinherited
cldImage ↔ CldImage
Cloudinary image object
latefinal
color → Color?
If non-null, this color is blended with each image pixel using colorBlendMode.
finalinherited
colorBlendMode → BlendMode?
Used to combine color with this image.
finalinherited
configuration → CldImageWidgetConfiguration?
final
errorListener → ValueChanged<Object>?
Listener to be called when images fails to load.
finalinherited
errorWidget → LoadingErrorWidgetBuilder?
Widget displayed while the target imageUrl failed loading.
finalinherited
fadeInCurve → Curve
The curve of the fade-in animation for the imageUrl.
finalinherited
fadeInDuration → Duration
The duration of the fade-in animation for the imageUrl.
finalinherited
fadeOutCurve → Curve
The curve of the fade-out animation for the placeholder.
finalinherited
fadeOutDuration → Duration?
The duration of the fade-out animation for the placeholder.
finalinherited
filterQuality → FilterQuality
Target the interpolation quality for image scaling.
finalinherited
fit → BoxFit?
How to inscribe the image into the space allocated during layout.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
height → double?
If non-null, require the image to have this height.
finalinherited
httpHeaders → Map<String, String>?
Optional headers for the http request of the image url
finalinherited
imageBuilder → ImageWidgetBuilder?
Optional builder to further customize the display of the image.
finalinherited
imageUrl → String
The target image that is displayed.
finalinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
matchTextDirection → bool
Whether to paint the image in the direction of the TextDirection.
finalinherited
maxHeightDiskCache → int?
Will resize the image and store the resized image in the disk cache.
finalinherited
maxWidthDiskCache → int?
Will resize the image and store the resized image in the disk cache.
finalinherited
memCacheHeight → int?
Will resize the image in memory to have a certain height using ResizeImage
finalinherited
memCacheWidth → int?
Will resize the image in memory to have a certain width using ResizeImage
finalinherited
placeholder → PlaceholderWidgetBuilder?
Widget displayed while the target imageUrl is loading.
finalinherited
placeholderFadeInDuration → Duration?
The duration of the fade-in animation for the placeholder.
finalinherited
progressIndicatorBuilder → ProgressIndicatorBuilder?
Widget displayed while the target imageUrl is loading.
finalinherited
repeat → ImageRepeat
How to paint any portions of the layout bounds not covered by the image.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
useOldImageOnUrlChange → bool
When set to true it will animate from the old image to the new image if the url changes.
finalinherited
width → double?
If non-null, require the image to have this width.
finalinherited

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited