VideoEvent class

Implementers

Constructors

VideoEvent({required TrackingType trackingType, required String eventName, EventDetails? eventDetails})

Properties

eventDetails ↔ EventDetails
getter/setter pair
eventName ↔ String
getter/setter pair
eventTime ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trackingType ↔ TrackingType
getter/setter pair

Methods

createCustomerData(Map<String, String>? trackingData, Map<String, dynamic>? providedData) → Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDictionary() → EventDetails
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

createVideoPlayerObject() → EventDetails