VideoPlayEvent class

Inheritance

Constructors

VideoPlayEvent({TrackingType trackingType = TrackingType.auto, Map<String, dynamic>? providedData})

Properties

eventDetails ↔ EventDetails
getter/setter pairinherited
eventName ↔ String
getter/setter pairinherited
eventTime ↔ int
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trackingType ↔ TrackingType
getter/setter pairinherited

Methods

createCustomerData(Map<String, String>? trackingData, Map<String, dynamic>? providedData) → Map<String, dynamic>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDictionary() → EventDetails
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited