VideoEventsManager class

Constructors

VideoEventsManager({String? cloudName, String? publicId})

Properties

CLD_ANALYTICS_ENDPOINT_PRODUCTION_URL → String
final
cloudName ↔ String?
getter/setter pair
eventQueue ↔ List<VideoEvent>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
publicId ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timer ↔ Timer?
getter/setter pair
trackingType ↔ TrackingType
getter/setter pair
userId ↔ String
getter/setter pair
viewId ↔ String
getter/setter pair

Methods

addEventToQueue(VideoEvent event) → void
buildEventsData(List<VideoEvent> childEvents) → Future<MultipartFile>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendEvents() → Future<void>
sendEventToEndpoint(List<VideoEvent> childEvents) → Future<void>
sendLoadMetadataEvent(int duration, {Map<String, dynamic>? providedData}) → void
sendPauseEvent() → void
sendPlayEvent({Map<String, dynamic>? providedData}) → void
sendViewEndEvent({Map<String, dynamic>? providedData}) → void
sendViewStartEvent(String videoUrl, {Map<String, dynamic>? providedData}) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited