CldVideoController class

Inheritance
Mixed-in types

Constructors

CldVideoController({required String publicId, Cloudinary? cloudinary, String? version, String? extension, String? urlSuffix, String? assetType, String? deliveryType, Transformation? transformation, bool? automaticStreamingProfile})
CldVideoController.networkUrl(Uri url)

Properties

analytics ↔ bool
getter/setter pair
closedCaptionFile → Future<ClosedCaptionFile>?
Returns the file containing closed captions for the video, if any.
no setterinherited
dataSource → String
The URI to the video file. This will be in different formats depending on the DataSourceType of the original video.
finalinherited
dataSourceType → DataSourceType
Describes the type of data source this VideoPlayerController is constructed with.
finalinherited
eventsManager ↔ VideoEventsManager
getter/setter pairoverride
eventsSent ↔ EventsSent
getter/setter pairinherited
formatHint → VideoFormat?
Android only. Will override the platform's generic file format detection with whatever is set here.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
httpHeaders → Map<String, String>
HTTP headers used for the request to the dataSource. Only for VideoPlayerController.network. Always empty for other video types.
finalinherited
package → String?
Only set for asset videos. The package that the asset was loaded from.
finalinherited
playerId → int
This is just exposed for testing. It shouldn't be used by anyone depending on the plugin.
no setterinherited
position → Future<Duration?>
The position in the current video.
no setterinherited
publicId ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri ↔ Uri
latefinaloverride
value ↔ VideoPlayerValue
The current value stored in this notifier.
getter/setter pairinherited
videoPlayerOptions → VideoPlayerOptions?
Provide additional configuration options (optional). Like setting the audio mode to mix
finalinherited
viewType → VideoViewType
The requested display mode for the video.
finalinherited

Methods

addCustomListeners() → void
inherited
addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → Future<void>
Discards any resources used by the object.
override
getAudioTracks() → Future<List<VideoAudioTrack>>
Gets the available audio tracks for the video.
inherited
getVideoTracks() → Future<List<VideoTrack>>
Gets the available video tracks for the video.
inherited
initialize() → Future<void>
Attempts to open the given dataSource and load metadata about the video.
override
isAudioTrackSupportAvailable() → bool
Returns whether audio track selection is supported on this platform.
inherited
isVideoTrackSupportAvailable() → bool
Whether video track selection is supported on this platform.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
pause() → Future<void>
Pauses the video.
inherited
play() → Future<void>
Starts playing the video.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
removeListeners() → void
inherited
seekTo(Duration position) → Future<void>
Sets the video's current timestamp to be at moment. The next time the video is played it will resume from the given moment.
inherited
selectAudioTrack(String trackId) → Future<void>
Selects which audio track is chosen for playback from its trackId
inherited
selectVideoTrack(VideoTrack? track) → Future<void>
Selects which video track is chosen for playback.
inherited
setAnalytics(AnalyticsType analyticsType, {String? cloudName, String? publicId}) → void
setCaptionOffset(Duration offset) → void
Sets the caption offset.
inherited
setClosedCaptionFile(Future<ClosedCaptionFile>? closedCaptionFile) → Future<void>
Sets a closed caption file.
inherited
setLooping(bool looping) → Future<void>
Sets whether or not the video should loop after playing once. See also VideoPlayerValue.isLooping.
inherited
setPlaybackSpeed(double speed) → Future<void>
Sets the playback speed of this.
inherited
setPreventsDisplaySleepDuringVideoPlayback(bool preventsDisplaySleepDuringVideoPlayback) → Future<void>
Sets whether the screen is prevented from sleeping during video playback.
inherited
setVolume(double volume) → Future<void>
Sets the audio volume of this.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited